from quixote import get_request, get_response, get_session, redirect
from quixote.directory import Directory, AccessControlled
from quixote.html import TemplateIO, htmltext

import wcs
import wcs.admin.root

from qommon.backoffice.menu import html_top
from qommon import get_cfg
from qommon import errors
from qommon.form import *
from qommon import misc, get_logger

from wcs.formdef import FormDef
from wcs.categories import Category

class FormDirectory(Directory):
    _q_exports = ['options', 'disable', 'enable']

    def __init__(self, formdef):
        self.formdef = formdef

    def enable(self):
        self.formdef.disabled = False
        self.formdef.store()
        return redirect('..')

    def disable(self):
        self.formdef.disabled = True
        self.formdef.store()
        return redirect('..')

    def options(self):
        form = Form(enctype='multipart/form-data')
        form.add_submit('submit', _('Submit'))
        form.add_submit('cancel', _('Cancel'))
        form.add_submit('disable', _('Disable Form'))

        if form.get_submit() == 'disable':
            return self.disable()

        if form.get_submit() == 'cancel':
            return redirect('..')

        if form.is_submitted() and not form.has_errors():
            return redirect('..')

        r = TemplateIO(html=True)
        r += htmltext('<p>')
        r += _('No available options')
        r += htmltext('</p>')
        r += form.render()
        return r.getvalue()


def is_forms_admin():
    user = get_request().user
    if not user:
        return False
    admin_role = get_cfg('aq-permissions', {}).get('forms', None)
    if not (user.is_admin or admin_role in (user.roles or [])):
        return False
    return True


class FormsDirectory(AccessControlled, Directory):
    _q_exports = ['', 'new', 'listing', 'update_order']
    label = N_('Forms')

    def _q_access(self):
        get_response().breadcrumb.append(('forms/', _('Forms Management')))

    def _q_index(self):
        html_top('management', _('Forms Management'))
        r = TemplateIO(html=True)

        session = get_session()
        user = get_request().user

        is_admin = is_forms_admin()

        l = []
        l2 = []
        if user:
            for formdef in FormDef.select(order_by='name', ignore_errors=True):
                if not formdef.disabled:
                    if is_admin or formdef.is_of_concern_for(user):
                        l.append(formdef)
                elif is_admin:
                    l.append(formdef)

        cats = Category.select(order_by = 'name')
        lists = []
        for c in cats:
            t = [x for x in l if str(x.category_id) == str(c.id)]
            if t:
                lists.append((c.name, t))
        t = [x for x in l if x.category_id is None]
        if t:
            lists.append((None, t))

        mid_term = ((len(lists) * 2) + sum([len(x[-1]) for x in lists])) / 2
        count = 0
        in_second_column = False
        r += htmltext('<div class="splitcontent-left">')
        for cat_name, formdefs in lists:
            if not in_second_column and count > mid_term:
                r += htmltext('</div>')
                r += htmltext('<div class="splitcontent-right">')
            count += 2 + len(formdefs)
            if len([x for x in formdefs if not x.disabled]) == 0:
                # all forms are disabled, dim the block
                r += htmltext('<div class="bo-block dimmed-block">')
            else:
                r += htmltext('<div class="bo-block">')
            if cat_name:
                r += htmltext('<h2>%s</h2>') % cat_name
            elif len(lists) > 1:
                r += htmltext('<h2>%s</h2>') % _('Misc')
            r += htmltext('<ul>')
            for formdef in formdefs:
                r += htmltext('<li>')
                if formdef.disabled:
                    r += htmltext('<span class="disabled">')
                r += htmltext('<a href="../%s/">%s</a>') % (formdef.url_name, formdef.name)
                if formdef.disabled:
                    r += htmltext('</span>')
                if is_admin:
                    if formdef.disabled:
                        r += htmltext(' (<a href="%s/enable">%s</a>)') % (formdef.id, _('enable'))
                    else:
                        r += htmltext(' (<a href="%s/disable">%s</a>)') % (formdef.id, _('disable'))
                r += htmltext('</li>')
            r += htmltext('</ul>')
            r += htmltext('</div>')
        r += htmltext('</div>')

        get_logger().info('forms backoffice - home')
        return r.getvalue()

    def _q_lookup(self, component):
        try:
            formdef = FormDef.get(component)
        except KeyError:
            raise errors.TraversalError()
        get_response().breadcrumb.append((str(formdef.id), formdef.name))
        return FormDirectory(formdef)

    def listing(self):
        return redirect('.')

